<?php
namespace ApacheSolrForTypo3\Tika\ContextMenu;

use TYPO3\CMS\Backend\ContextMenu\ItemProviders\AbstractProvider;
use TYPO3\CMS\Core\Resource\File;

class Preview extends AbstractProvider{

    protected $itemsConfiguration = [
        'tika_preview' => [
            'type' => 'item',
            'label' => 'Tika Preview', // you can use "LLL:" syntax here
            'iconIdentifier' => 'actions-document-view',
            'callbackAction' => 'tikaPreview'
        ]
    ];

    /**
     * Checks if this provider may be called to provide the list of context menu items for given table.
     *
     * @return bool
     */
    public function canHandle(): bool
    {
        if (!$GLOBALS['BE_USER']->isAdmin()) {
            return false;
        }

        // Current table is: $this->table
        // Current UID is: $this->identifier
        if ($this->table !== 'sys_file') {
            return false;
        }

        $resourceFactory = \TYPO3\CMS\Core\Resource\ResourceFactory::getInstance();
        $item = $resourceFactory->retrieveFileOrFolderObject($this->identifier);

        // we only handle files, no folders
        return ($item instanceof File);
    }

    /**
     * Returns the provider priority which is used for determining the order in which providers are processing items
     * to the result array. Highest priority means provider is evaluated first.
     *
     * This item provider should be called after PageProvider which has priority 100.
     *
     * BEWARE: Returned priority should logically not clash with another provider.
     *   Please check @see \TYPO3\CMS\Backend\ContextMenu\ContextMenu::getAvailableProviders() if needed.
     *
     * @return int
     */
    public function getPriority(): int
    {
        return 90;
    }

    /**
     * Registers the additional JavaScript RequireJS callback-module which will allow to display a notification
     * whenever the user tries to click on the "Hello World" item.
     * The method is called from AbstractProvider::prepareItems() for each context menu item.
     *
     * @param string $itemName
     * @return array
     */
    protected function getAdditionalAttributes(string $itemName): array
    {
        return ['data-callback-module' => 'TYPO3/CMS/Tika/ContextMenuActions'];
    }

    /**
     * This method adds custom item to list of items generated by item providers with higher priority value (PageProvider)
     * You could also modify existing items here.
     * The new item is added after the 'info' item.
     *
     * @param array $items
     * @return array
     */
    public function addItems(array $items): array
    {

        $this->initDisabledItems();
        $localItems = $this->prepareItems($this->itemsConfiguration);
        $items = $items + $localItems;
        //passes array of items to the next item provider
        return $items;
    }

    /**
     * This method is called for each item this provider adds and checks if given item can be added
     *
     * @param string $itemName
     * @param string $type
     * @return bool
     */
    protected function canRender(string $itemName, string $type): bool
    {
        // checking if item is disabled through TSConfig
        if (in_array($itemName, $this->disabledItems, true)) {
            return false;
        }
        switch ($itemName) {
            case 'tika_preview':
                $canRender = true;
                break;
            default:
                $canRender = false;
        }
        return $canRender;
    }
}
